==> Paws-0.25.tar.gz: Paws-0.25/lib/Paws/EC2/DescribePlacementGroups.pm <==

package Paws::EC2::DescribePlacementGroups;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
  has Filters => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Filter]', traits => ['NameInRequest'], request_name => 'Filter' );
  has GroupNames => (is => 'ro', isa => 'ArrayRef[Str]', traits => ['NameInRequest'], request_name => 'groupName' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribePlacementGroups');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DescribePlacementGroupsResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DescribePlacementGroups - Arguments for method DescribePlacementGroups on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribePlacementGroups on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method DescribePlacementGroups.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribePlacementGroups.

As an example:

  $service_obj->DescribePlacementGroups(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 Filters => ArrayRef[L<Paws::EC2::Filter>]

One or more filters.

=over

=item *

C<group-name> - The name of the placement group.

=item *

C<state> - The state of the placement group (C<pending> | C<available>
| C<deleting> | C<deleted>).

=item *

C<strategy> - The strategy of the placement group (C<cluster>).

=back




=head2 GroupNames => ArrayRef[Str]

One or more placement group names.

Default: Describes all your placement groups, or only those otherwise
specified.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribePlacementGroups in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.29.tar.gz: Paws-0.29/lib/Paws/EC2/DescribePlacementGroups.pm <==

package Paws::EC2::DescribePlacementGroups;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );
  has Filters => (is => 'ro', isa => 'ArrayRef[Paws::EC2::Filter]', traits => ['NameInRequest'], request_name => 'Filter' );
  has GroupNames => (is => 'ro', isa => 'ArrayRef[Str|Undef]', traits => ['NameInRequest'], request_name => 'groupName' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribePlacementGroups');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::DescribePlacementGroupsResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::DescribePlacementGroups - Arguments for method DescribePlacementGroups on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribePlacementGroups on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method DescribePlacementGroups.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribePlacementGroups.

As an example:

  $service_obj->DescribePlacementGroups(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 Filters => ArrayRef[L<Paws::EC2::Filter>]

One or more filters.

=over

=item *

C<group-name> - The name of the placement group.

=item *

C<state> - The state of the placement group (C<pending> | C<available>
| C<deleting> | C<deleted>).

=item *

C<strategy> - The strategy of the placement group (C<cluster>).

=back




=head2 GroupNames => ArrayRef[Str|Undef]

One or more placement group names.

Default: Describes all your placement groups, or only those otherwise
specified.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribePlacementGroups in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
